==> openGion6.9.7.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE54S.sql <==
/****************************************************************************/
/* GE54 ( 帳票定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/03/29 14:26:43                                            */
/****************************************************************************/

CREATE TABLE GE54 (
   SYSTEM_ID        varchar (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID           */
 , LISTID           varchar (   10 )                    NOT NULL            /*  20 帳票ID           */
 , LISTNAME         varchar (  100 )                                        /*  30 帳票名称         */
 , MODELDIR         varchar (  100 )                    NOT NULL            /*  40 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        varchar (   20 )                    NOT NULL            /*  50 雛型ﾌｧｲﾙ名       */
 , FGCUT            varchar (    1 )                                        /*  60 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , HSQL             varchar ( 4000 )                                        /*  70 ﾍｯﾀﾞｰSQL         */
 , FSQL             varchar ( 4000 )                                        /*  80 ﾌｯﾀｰSQL          */
 , BSQL             varchar ( 4000 )                                        /*  90 ﾎﾞﾃﾞｨSQL         */
 , COMMENTS         varchar (  500 )                                        /* 100 ｺﾒﾝﾄ             */
 , FGLOCAL          varchar (    1 )        DEFAULT '0' NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , FGDIRECT         varchar (    1 )        DEFAULT '0' NOT NULL            /* 120 ﾀﾞｲﾚｸﾄ           */
 , RELEASE_NOTES    varchar (  120 )                                        /* 130 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         varchar (   20 )                                        /* 140 設変番号         */
 , FGJ              varchar (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            varchar (   14 )                                        /* 820 登録日時         */
 , PGSET            varchar (   10 )                                        /* 830 作成PG           */
 , PGPSET           varchar (   10 )                                        /* 840 作成親PG         */
 , USRSET           varchar (   10 )                                        /* 850 作成社員         */
 , DYUPD            varchar (   14 )                                        /* 860 更新日時         */
 , PGUPD            varchar (   10 )                                        /* 870 更新PG           */
 , PGPUPD           varchar (   10 )                                        /* 880 更新親PG         */
 , USRUPD           varchar (   10 )                                        /* 890 更新者           */
);

==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE54S.sql <==
/****************************************************************************/
/* GE54 ( 帳票定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE54 (
   SYSTEM_ID        varchar (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID           */
 , LISTID           varchar (   10 )                    NOT NULL            /*  20 帳票ID           */
 , LISTNAME         varchar (  100 )                                        /*  30 帳票名称         */
 , MODELDIR         varchar (  100 )                    NOT NULL            /*  40 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        varchar (   20 )                    NOT NULL            /*  50 雛型ﾌｧｲﾙ名       */
 , FGCUT            varchar (    1 )                                        /*  60 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , HSQL             varchar ( 4000 )                                        /*  70 ﾍｯﾀﾞｰSQL         */
 , FSQL             varchar ( 4000 )                                        /*  80 ﾌｯﾀｰSQL          */
 , BSQL             varchar ( 4000 )                                        /*  90 ﾎﾞﾃﾞｨSQL         */
 , COMMENTS         varchar (  500 )                                        /* 100 ｺﾒﾝﾄ             */
 , FGLOCAL          varchar (    1 )        DEFAULT '0' NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , FGDIRECT         varchar (    1 )        DEFAULT '0' NOT NULL            /* 120 ﾀﾞｲﾚｸﾄ           */
 , RELEASE_NOTES    varchar (  120 )                                        /* 130 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         varchar (   20 )                                        /* 140 設変番号         */
 , OPTIONS          varchar ( 1000 )                                        /* 150 オプション       */
 , FGJ              varchar (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            varchar (   14 )                                        /* 820 登録日時         */
 , PGSET            varchar (   10 )                                        /* 830 作成PG           */
 , PGPSET           varchar (   10 )                                        /* 840 作成親PG         */
 , USRSET           varchar (   10 )                                        /* 850 作成者           */
 , DYUPD            varchar (   14 )                                        /* 860 更新日時         */
 , PGUPD            varchar (   10 )                                        /* 870 更新PG           */
 , PGPUPD           varchar (   10 )                                        /* 880 更新親PG         */
 , USRUPD           varchar (   10 )                                        /* 890 更新者           */
);
